Create a non-white color palette for ggplot2 based on Polychrome::glasbey.colors
create_multi_color_palette.RdGenerate a color palette for ggplot2 with specified number of color, white is intentionally removed.
create_multi_color_palette.RdGenerate a color palette for ggplot2 with specified number of color, white is intentionally removed.