Function cleaning correlation matrix to pairwise dataframe
flatten_correlation_matrix.RdThis function takes a correlation matrix and a p-value matrix from correlation matrix computing clean the matrix to pairwise terms credit to https://www.sthda.com/english/wiki/correlation-matrix-a-quick-start-guide-to-analyze-format-and-visualize-a-correlation-matrix-using-r-software