A wrapper preparing pairwise distribution comparison report normally distributed variables
pairwise_wilcox_report.RdThis wrapper will run a stats::pairwise.wilcox.test for each element mentioned in "variable" while stratified across different value in "by" column and prepare a barchart for illustration.
Arguments
- data
data.frame, the source data
- variable
str or vector of str, the variable you are interested in
- by
str, the categorical variable stratifying the dataset
- p_threshold
optional float, the significance threshold, 0.05 by default
- adjustment_method
optional str, the correction adjusting pairwise, Benjamini-Hochberg FDR by default