Function wrapper compute pairwise correlation matrix and return as a visualization format
correlation_matrix_plot.RdIf no variable list provided, the function will clean all the value as numerical matrix and compute the correlation matrix
Arguments
- data
data.frame, the data table.
- variable
optional character vector, the list of variable included in computation, all columns by default
- p_threshold
optional float, the only the rows with p-value less than this value will be included, Null default(all included)
- font_size
optional int, the size of row/column labels, default 5